@@ -6,8 +6,7 @@ use strict;
 
 use vars qw(@ISA $VERSION $CLASS $STRICT $LAX *declare *qv);
 
-$VERSION = '0.90';
-$VERSION = eval($VERSION);
+$VERSION = 0.92;
 
 $CLASS = 'version';
 
@@ -124,7 +123,7 @@ if ( $@ ) { # don't have the XS version installed
     *version::qv = \&version::vpp::qv;
     *version::declare = \&version::vpp::declare;
     *version::_VERSION = \&version::vpp::_VERSION;
-    if ($] >= 5.009000 && $] < 5.011004) {
+    if ($] >= 5.009000) {
 	no strict 'refs';
 	*version::stringify = \&version::vpp::stringify;
 	*{'version::(""'} = \&version::vpp::stringify;
@@ -139,7 +138,7 @@ else { # use XS module
     *version::qv = \&version::vxs::qv;
     *version::_VERSION = \&version::vxs::_VERSION;
     *version::vcmp = \&version::vxs::VCMP;
-    if ($] >= 5.009000 && $] < 5.011004) {
+    if ($] >= 5.009000) {
 	no strict 'refs';
 	*version::stringify = \&version::vxs::stringify;
 	*{'version::(""'} = \&version::vxs::stringify;
