@@ -121,7 +121,7 @@ use strict;
 use POSIX qw/locale_h/;
 use locale;
 use vars qw ($VERSION @ISA @REGEXS);
-$VERSION = 0.91;
+$VERSION = 0.92;
 
 use overload (
     '""'       => \&stringify,
@@ -135,7 +135,7 @@ use overload (
 eval "use warnings";
 if ($@) {
     eval '
-	package 
+	package
 	warnings;
 	sub enabled {return $^W;}
 	1;
@@ -254,7 +254,7 @@ dotted_decimal_version:
 		}
 		$j = 0;
 	    }
-	
+
 	    if ($strict && $i < 2) {
 		# requires v1.2.3
 		return BADVERSION($s,$errstr,"Invalid version format (dotted-decimal versions require at least three parts)");
@@ -273,6 +273,11 @@ dotted_decimal_version:
 	    }
 	}
 
+	# and we never support negative version numbers
+	if ($d eq '-') {
+	    return BADVERSION($s,$errstr,"Invalid version format (negative version number)");
+	}
+
 	# consume all of the integer part
 	while (isDIGIT($d)) {
 	    $d++;
@@ -417,7 +422,7 @@ sub scan_version {
     if ( !$qv && $width < 3 ) {
 	$$rv->{width} = $width;
     }
-    
+
     while (isDIGIT($pos)) {
 	$pos++;
     }
@@ -442,7 +447,7 @@ sub scan_version {
 			$orev = $rev;
  			$rev += $s * $mult;
  			$mult /= 10;
-			if (   (abs($orev) > abs($rev)) 
+			if (   (abs($orev) > abs($rev))
 			    || (abs($rev) > $VERSION_MAX )) {
 			    warn("Integer overflow in version %d",
 					   $VERSION_MAX);
@@ -461,7 +466,7 @@ sub scan_version {
 			$orev = $rev;
  			$rev += $end * $mult;
  			$mult *= 10;
-			if (   (abs($orev) > abs($rev)) 
+			if (   (abs($orev) > abs($rev))
 			    || (abs($rev) > $VERSION_MAX )) {
 			    warn("Integer overflow in version");
 			    $end = $s - 1;
@@ -469,7 +474,7 @@ sub scan_version {
 			    $vinf = 1;
 			}
  		    }
- 		} 
+ 		}
   	    }
 
   	    # Append revision
@@ -518,7 +523,7 @@ sub scan_version {
 	#  gcc version 3.3 20030304 (Apple Computer, Inc. build 1640)
 	#  for ( len = 2 - len; len > 0; len-- )
 	#  av_push(MUTABLE_AV(sv), newSViv(0));
-	# 
+	#
 	$len = 2 - $len;
 	while ($len-- > 0) {
 	    push @av, 0;
@@ -558,7 +563,7 @@ sub new
 	my ($class, $value) = @_;
 	my $self = bless ({}, ref ($class) || $class);
 	my $qv = FALSE;
-	
+
 	if ( ref($value) && eval('$value->isa("version")') ) {
 	    # Can copy the elements directly
 	    $self->{version} = [ @{$value->{version} } ];
@@ -597,7 +602,7 @@ sub new
 	    $value = sprintf("%.9f",$value);
 	    $value =~ s/(0+)$//; # trim trailing zeros
 	}
-	
+
 	my $s = scan_version($value, \$self, $qv);
 
 	if ($s) { # must be something left over
@@ -610,7 +615,7 @@ sub new
 
 *parse = \&new;
 
-sub numify 
+sub numify
 {
     my ($self) = @_;
     unless (_verify($self)) {
@@ -651,7 +656,7 @@ sub numify
     return $string;
 }
 
-sub normal 
+sub normal
 {
     my ($self) = @_;
     unless (_verify($self)) {
@@ -694,9 +699,9 @@ sub stringify
 	require Carp;
 	Carp::croak("Invalid version object");
     }
-    return exists $self->{original} 
-    	? $self->{original} 
-	: exists $self->{qv} 
+    return exists $self->{original}
+    	? $self->{original}
+	: exists $self->{qv}
 	    ? $self->normal
 	    : $self->numify;
 }
@@ -734,8 +739,8 @@ sub vcmp
     }
 
     # tiebreaker for alpha with identical terms
-    if ( $retval == 0 
-	&& $l == $r 
+    if ( $retval == 0
+	&& $l == $r
 	&& $left->{version}[$m] == $right->{version}[$m]
 	&& ( $lalpha || $ralpha ) ) {
 
@@ -767,7 +772,7 @@ sub vcmp
 	}
     }
 
-    return $retval;  
+    return $retval;
 }
 
 sub vbool {
@@ -775,8 +780,8 @@ sub vbool {
     return vcmp($self,$self->new("0"),1);
 }
 
-sub vnoop { 
-    require Carp; 
+sub vnoop {
+    require Carp;
     Carp::croak("operation not supported with version object");
 }
 
@@ -834,7 +839,7 @@ sub _is_non_alphanumeric {
 sub _un_vstring {
     my $value = shift;
     # may be a v-string
-    if ( length($value) >= 3 && $value !~ /[._]/ 
+    if ( length($value) >= 3 && $value !~ /[._]/
 	&& _is_non_alphanumeric($value)) {
 	my $tvalue;
 	if ( $] ge 5.008_001 ) {
@@ -884,15 +889,16 @@ sub _VERSION {
     }
 
     my $version = eval "\$$class\::VERSION";
-    if ( defined $version ) {
-	local $^W if $] <= 5.008;
-	$version = version::vpp->new($version);
-    }
 
     if ( defined $req ) {
-	unless ( defined $version ) {
+	my $ver;
+	if ( defined $version ) {
+	    local $^W if $] <= 5.008;
+	    $ver = version::vpp->new($version);
+	}
+	else {
 	    require Carp;
-	    my $msg =  $] < 5.006 
+	    my $msg =  $] < 5.006
 	    ? "$class version $req required--this is only version "
 	    : "$class does not define \$$class\::VERSION"
 	      ."--version check failed";
@@ -907,26 +913,26 @@ sub _VERSION {
 
 	$req = version::vpp->new($req);
 
-	if ( $req > $version ) {
+	if ( $req > $ver ) {
 	    require Carp;
 	    if ( $req->is_qv ) {
-		Carp::croak( 
+		Carp::croak(
 		    sprintf ("%s version %s required--".
 			"this is only version %s", $class,
-			$req->normal, $version->normal)
+			$req->normal, $ver->normal)
 		);
 	    }
 	    else {
-		Carp::croak( 
+		Carp::croak(
 		    sprintf ("%s version %s required--".
 			"this is only version %s", $class,
-			$req->stringify, $version->stringify)
+			$req->stringify, $ver->stringify)
 		);
 	    }
 	}
     }
 
-    return defined $version ? $version->stringify : undef;
+    return $version;
 }
 
 1; #this line is important and will help the module return a true value
