@@ -21,9 +21,12 @@ some time when tokenizing.
 
 =cut
 */
-#if PERL_VERSION_LT(5,11,4)
 const char *
+#if VUTIL_REPLACE_CORE
+Perl_prescan_version2(pTHX_ const char *s, bool strict,
+#else
 Perl_prescan_version(pTHX_ const char *s, bool strict,
+#endif
 		     const char **errstr,
 		     bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha) {
     bool qv = (sqv ? *sqv : FALSE);
@@ -125,6 +128,11 @@ dotted_decimal_version:
 	    }
 	}
 
+	/* and we never support negative versions */
+	if ( *d == '-') {
+	    BADVERSION(s,errstr,"Invalid version format (negative version number)");
+	}
+
 	/* consume all of the integer part */
 	while (isDIGIT(*d))
 	    d++;
@@ -219,7 +227,6 @@ version_prescan_finish:
 	*salpha = alpha;
     return d;
 }
-#endif
 
 /*
 =for apidoc scan_version
@@ -244,7 +251,7 @@ it doesn't.
 */
 
 const char *
-#if VUTIL_USE_TWO_SUFFIX
+#if VUTIL_REPLACE_CORE
 Perl_scan_version2(pTHX_ const char *s, SV *rv, bool qv)
 #else
 Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
@@ -272,7 +279,7 @@ Perl_scan_version(pTHX_ const char *s, SV *rv, bool qv)
     while (isSPACE(*s)) /* leading whitespace is OK */
 	s++;
 
-    last = prescan_version(s, FALSE, &errstr, &qv, &saw_decimal, &width, &alpha);
+    last = PRESCAN_VERSION(s, FALSE, &errstr, &qv, &saw_decimal, &width, &alpha);
     if (errstr) {
 	/* "undef" is a special case and not an error */
 	if ( ! ( *s == 'u' && strEQ(s,"undef")) ) {
@@ -435,7 +442,7 @@ want to upgrade the SV.
 */
 
 SV *
-#if VUTIL_USE_TWO_SUFFIX
+#if VUTIL_REPLACE_CORE
 Perl_new_version2(pTHX_ SV *ver)
 #else
 Perl_new_version(pTHX_ SV *ver)
@@ -525,7 +532,7 @@ to force this SV to be interpreted as an "extended" version.
 */
 
 SV *
-#if VUTIL_USE_TWO_SUFFIX
+#if VUTIL_REPLACE_CORE
 Perl_upg_version2(pTHX_ SV *ver, bool qv)
 #else
 Perl_upg_version(pTHX_ SV *ver, bool qv)
@@ -637,7 +644,7 @@ confused by derived classes which may contain additional hash entries):
 */
 
 SV *
-#if VUTIL_USE_TWO_SUFFIX
+#if VUTIL_REPLACE_CORE
 Perl_vverify2(pTHX_ SV *vs)
 #else
 Perl_vverify(pTHX_ SV *vs)
@@ -674,9 +681,12 @@ contained within the RV.
 =cut
 */
 
-#if PERL_VERSION_LT(5,11,4)
 SV *
+#if VUTIL_REPLACE_CORE
+Perl_vnumify2(pTHX_ SV *vs)
+#else
 Perl_vnumify(pTHX_ SV *vs)
+#endif
 {
     I32 i, len, digit;
     int width;
@@ -739,7 +749,6 @@ Perl_vnumify(pTHX_ SV *vs)
     }
     return sv;
 }
-#endif
 
 /*
 =for apidoc vnormal
@@ -755,9 +764,12 @@ contained within the RV.
 =cut
 */
 
-#if PERL_VERSION_LT(5,11,4)
 SV *
+#if VUTIL_REPLACE_CORE
+Perl_vnormal2(pTHX_ SV *vs)
+#else
 Perl_vnormal(pTHX_ SV *vs)
+#endif
 {
     I32 i, len, digit;
     bool alpha = FALSE;
@@ -803,7 +815,6 @@ Perl_vnormal(pTHX_ SV *vs)
     }
     return sv;
 }
-#endif
 
 /*
 =for apidoc vstringify
@@ -817,7 +828,7 @@ the original version contained 1 or more dots, respectively
 */
 
 SV *
-#if VUTIL_USE_TWO_SUFFIX
+#if VUTIL_REPLACE_CORE
 Perl_vstringify2(pTHX_ SV *vs)
 #else
 Perl_vstringify(pTHX_ SV *vs)
@@ -840,9 +851,9 @@ Perl_vstringify(pTHX_ SV *vs)
     }
     else {
 	if ( hv_exists(MUTABLE_HV(vs), "qv", 2) )
-	    return vnormal(vs);
+	    return VNORMAL(vs);
 	else
-	    return vnumify(vs);
+	    return VNUMIFY(vs);
     }
 }
 
@@ -855,9 +866,12 @@ converted into version objects.
 =cut
 */
 
-#if PERL_VERSION_LT(5,11,4)
 int
+#if VUTIL_REPLACE_CORE
+Perl_vcmp2(pTHX_ SV *lhv, SV *rhv)
+#else
 Perl_vcmp(pTHX_ SV *lhv, SV *rhv)
+#endif
 {
     I32 i,l,m,r,retval;
     bool lalpha = FALSE;
@@ -936,4 +950,3 @@ Perl_vcmp(pTHX_ SV *lhv, SV *rhv)
     }
     return retval;
 }
-#endif
